@@ -17,52 +17,56 @@ which accepts a single argument <hook>. That argument will
 contain the hook that is being activated.
 """
 # ========================================================================
-__version__ = "$Revision: 1.18 $"
 __author__  = "K. Hilbert <Karsten.Hilbert@gmx.net>"
 __license__ = "GPL v2 or later (details at http://www.gnu.org)"
 
-
 # stdlib
-import os, sys, stat, logging
-
-_log = logging.getLogger('gm.hook')
-_log.info(__version__)
+import os
+import sys
+import stat
+import logging
+import io
 
 
 # GNUmed libs
 if __name__ == '__main__':
 	sys.path.insert(0, '../../')
-from Gnumed.pycommon import gmDispatcher, gmTools
+from Gnumed.pycommon import gmDispatcher
+from Gnumed.pycommon import gmTools
 
+
+_log = logging.getLogger('gm.hook')
 # ========================================================================
 known_hooks = [
-	u'post_patient_activation',
-	u'post_person_creation',
+	'post_patient_activation',
+	'post_person_creation',
 
-	u'shutdown-post-GUI',
-	u'startup-after-GUI-init',
-	u'startup-before-GUI',
+	'after_waiting_list_modified',
 
-	u'request_user_attention',
-	u'app_activated_startup',
-	u'app_activated',
-	u'app_deactivated',
+	'shutdown-post-GUI',
+	'startup-after-GUI-init',
+	'startup-before-GUI',
 
-	u'after_substance_intake_modified',
-	u'after_test_result_modified',
-	u'after_soap_modified',
-	u'after_code_link_modified',
+	'request_user_attention',
+	'app_activated_startup',
+	'app_activated',
+	'app_deactivated',
 
-	u'after_new_doc_created',
-	u'before_print_doc',
-	u'before_fax_doc',
-	u'before_mail_doc',
-	u'before_print_doc_part',
-	u'before_fax_doc_part',
-	u'before_mail_doc_part',
-	u'before_external_doc_access',
+	'after_substance_intake_modified',
+	'after_test_result_modified',
+	'after_soap_modified',
+	'after_code_link_modified',
 
-	u'db_maintenance_warning'
+	'after_new_doc_created',
+	'before_print_doc',
+	'before_fax_doc',
+	'before_mail_doc',
+	'before_print_doc_part',
+	'before_fax_doc_part',
+	'before_mail_doc_part',
+	'before_external_doc_access',
+
+	'db_maintenance_warning'
 ]
 
 _log.debug('known hooks:')
@@ -88,7 +92,7 @@ def import_hook_module(reimport=False):
 
 	if not os.access(full_script, os.F_OK):
 		_log.warning('creating default hook script')
-		f = open(full_script, 'w')
+		f = io.open(full_script, mode = 'wt', encoding = 'utf8')
 		f.write("""
 # known hooks:
 #  %s
@@ -129,41 +133,74 @@ def run_script(hook=None):
 
 	try:
 		tmp = gmTools.import_module_from_directory(script_path, script_name)
-	except StandardError:
+	except Exception:
 		_log.exception('cannot import hook script')
 		return False
 
 	hook_module = tmp
 #	if reimport:
-#		reload(tmp)			# this has well-known shortcomings !
+#		imp.reload(tmp)			# this has well-known shortcomings !
 
 	_log.info('hook script: %s', full_script)
 	return True
+
 # ========================================================================
+__current_hook_stack = []
+
 def run_hook_script(hook=None):
 	# NOTE: this just *might* be a huge security hole
 
+	_log.info('told to pull hook [%s]', hook)
+
 	if hook not in known_hooks:
 		raise ValueError('run_hook_script(): unknown hook [%s]' % hook)
 
 	if not import_hook_module(reimport = False):
+		_log.debug('cannot import hook module, not pulling hook')
 		return False
 
+	if hook in __current_hook_stack:
+		_log.error('hook-code cycle detected, aborting')
+		_log.error('current hook stack: %s', __current_hook_stack)
+		return False
+
+	__current_hook_stack.append(hook)
+
 	try:
 		hook_module.run_script(hook = hook)
-	except StandardError:
+	except Exception:
 		_log.exception('error running hook script for [%s]', hook)
 		gmDispatcher.send (
-			signal = u'statustext',
+			signal = 'statustext',
 			msg = _('Error running hook [%s] script.') % hook,
 			beep = True
 		)
+		if __current_hook_stack[-1] != hook:
+			_log.error('hook nesting errror detected')
+			_log.error('latest hook: expected [%s], found [%s]', hook, __current_hook_stack[-1])
+			_log.error('current hook stack: %s', __current_hook_stack)
+		else:
+			__current_hook_stack.pop()
 		return False
 
+	if __current_hook_stack[-1] != hook:
+		_log.error('hook nesting errror detected')
+		_log.error('latest hook: expected [%s], found [%s]', hook, __current_hook_stack[-1])
+		_log.error('current hook stack: %s', __current_hook_stack)
+	else:
+		__current_hook_stack.pop()
+
 	return True
+
 # ========================================================================
 if __name__ == '__main__':
 
+	if len(sys.argv) < 2:
+		sys.exit()
+
+	if sys.argv[1] != 'test':
+		sys.exit()
+
 	run_hook_script(hook = 'shutdown-post-GUI')
 	run_hook_script(hook = 'invalid hook')
 
