@@ -237,10 +237,11 @@ def activate_locale():
 		_log.exception('Windows does not support locale.LC_ALL')
 	except Exception:
 		_log.exception('error activating user-default locale')
+		_log.log_stack_trace()
 	__log_locale_settings('locale settings after activating user-default locale')
 	# assume en_EN if we did not find any locale settings
 	if loc in [None, 'C']:
-		_log.error('the current system locale is still [None] or [C], assuming [en_EN]')
+		_log.error('the current system locale is still [None] or [C], falling back to [en_EN]')
 		system_locale = "en_EN"
 	else:
 		system_locale = loc
