@@ -17,22 +17,19 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.8.5 (database v22.15)',
-	'GNUmed 1.8.5 Release Notes:
+	'Release Notes for GNUmed 1.8.7 (database v22.17)',
+	'GNUmed 1.8.7 Release Notes:
 
-	1.8.5
+	1.8.7
 
-FIX: image conversion w/o target extension [thanks ...]
-FIX: SVG icon [thanks freddii]
-FIX: lab: tab "most-recent": [x]ing "show missing" throws exception
-FIX: log: exception on inaccessible attributes
+FIX: export area: dumping encrypted/PDFed image to disk
+FIX: top panel: heart rate display
+FIX: paperwork: recalls list LaTeX template
 
-NEW: add CoVid-2019 vaccines
+	22.17
 
-	22.15
-
-FIX: message inbox view
+FIX: CREATE FUNCTION ... RETURNS OPAQUE -> TRIGGER [thanks SantyCW@es_AR]
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.15@1.8.5');
+select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.17@1.8.7');
